About
---
HiveD is a library for building distributed worker daemons.

Docs
---
Sorry, you'll have to check the docstrings, for now. =/

Authors
---
 - Dalton Barreto
 - Elias Tandel

License
---
Copyright 2014 Sieve. See LICENSE for more information.
